@@ -11,7 +11,7 @@ class LessonSubstitutionForm(forms.ModelForm):
 
     class Meta:
         model = LessonSubstitution
-        fields = ["week", "lesson_period", "subject", "teachers", "room", "cancelled"]
+        fields = ["subject", "teachers", "room", "cancelled", "comment"]
         widgets = {
             "teachers": ModelSelect2MultipleWidget(
                 search_fields=[
@@ -20,7 +20,7 @@ class LessonSubstitutionForm(forms.ModelForm):
                     "short_name__icontains",
                 ],
                 attrs={"data-minimum-input-length": 0, "class": "browser-default"},
-            )
+            ),
         }
 
 
